@@ -17,6 +17,7 @@ use core::{
     fmt,
     hash::{Hash, Hasher},
     ops::Deref,
+    str::FromStr,
 };
 
 mod repr;
@@ -181,6 +182,13 @@ impl<'a> From<&'a String> for CompactStr {
     }
 }
 
+impl FromStr for CompactStr {
+    type Err = core::convert::Infallible;
+    fn from_str(s: &str) -> Result<CompactStr, Self::Err> {
+        Ok(CompactStr::from(s))
+    }
+}
+
 impl fmt::Debug for CompactStr {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         fmt::Debug::fmt(self.as_str(), f)
